summaryrefslogtreecommitdiff
path: root/Userland/Libraries/LibPDF/Renderer.h
diff options
context:
space:
mode:
authorMatthew Olsson <matthewcolsson@gmail.com>2022-03-25 15:00:11 -0700
committerAndreas Kling <kling@serenityos.org>2022-03-31 18:10:45 +0200
commit468ceb1b489c5eaef559de4b5e8c5f8a71f79b25 (patch)
tree77257fd87b4430ffc08f8b5e674acad589193b64 /Userland/Libraries/LibPDF/Renderer.h
parent49cb040c279f2003032f1f6871acd36a66a7adb4 (diff)
downloadserenity-468ceb1b489c5eaef559de4b5e8c5f8a71f79b25.zip
LibPDF: Rename Command to Operator
This is the correct name, according to the spec
Diffstat (limited to 'Userland/Libraries/LibPDF/Renderer.h')
-rw-r--r--Userland/Libraries/LibPDF/Renderer.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/Userland/Libraries/LibPDF/Renderer.h b/Userland/Libraries/LibPDF/Renderer.h
index 60af100dde..90a23139f6 100644
--- a/Userland/Libraries/LibPDF/Renderer.h
+++ b/Userland/Libraries/LibPDF/Renderer.h
@@ -89,16 +89,16 @@ private:
PDFErrorOr<void> render();
- PDFErrorOr<void> handle_command(Command const&);
+ PDFErrorOr<void> handle_operator(Operator const&);
#define V(name, snake_name, symbol) \
PDFErrorOr<void> handle_##snake_name(Vector<Value> const& args);
- ENUMERATE_COMMANDS(V)
+ ENUMERATE_OPERATORS(V)
#undef V
PDFErrorOr<void> handle_text_next_line_show_string(Vector<Value> const& args);
PDFErrorOr<void> handle_text_next_line_show_string_set_spacing(Vector<Value> const& args);
PDFErrorOr<void> set_graphics_state_from_dict(NonnullRefPtr<DictObject>);
// shift is the manual advance given in the TJ command array
void show_text(String const&, float shift = 0.0f);
PDFErrorOr<NonnullRefPtr<ColorSpace>> get_color_space(Value const&);
@@ -89,16 +89,16 @@ private:
PDFErrorOr<void> handle_text_next_line_show_string_set_spacing(Vector<Value> const& args);
PDFErrorOr<void> set_graphics_state_from_dict(NonnullRefPtr<DictObject>);
- // shift is the manual advance given in the TJ command array
+ // shift is the manual advance given in the TJ operator array
void show_text(String const&, float shift = 0.0f);
PDFErrorOr<NonnullRefPtr<ColorSpace>> get_color_space(Value const&);